@@ -996,7 +996,8 @@ literalstring_parse (const char *string, lex_pos_ty *pos,
               for (n = 0, j = 0; j < 3; ++j)
                 {
                   n = n * 8 + c - '0';
-                  switch (*++p)
+                  c = *++p;
+                  switch (c)
                     {
                     default:
                       break;
@@ -1354,6 +1355,11 @@ phase5_get (token_ty *tp)
               }
             break;
           }
+        if (bufpos >= bufmax)
+          {
+            bufmax = 2 * bufmax + 10;
+            buffer = xrealloc (buffer, bufmax);
+          }
         buffer[bufpos] = 0;
         tp->type = token_type_string_literal;
         tp->string = xstrdup (buffer);
